Card Games API
==============

This section documents the API for all card game modules.

Poker
-----

The poker module implements Texas Hold'em and Omaha poker variants with AI opponents.

.. automodule:: card_games.poker.poker
   :members:
   :undoc-members:
   :show-inheritance:

Poker Core
~~~~~~~~~~

Hand evaluation and ranking utilities.

.. automodule:: card_games.poker.poker_core
   :members:
   :undoc-members:
   :show-inheritance:

Poker GUI
~~~~~~~~~

Graphical user interface for poker.

.. automodule:: card_games.poker.gui
   :members:
   :undoc-members:
   :show-inheritance:

Bluff (Cheat)
-------------

Implementation of the Bluff/Cheat card game with AI opponents.

.. automodule:: card_games.bluff.bluff
   :members:
   :undoc-members:
   :show-inheritance:

Bluff GUI
~~~~~~~~~

Graphical user interface for Bluff.

.. automodule:: card_games.bluff.gui
   :members:
   :undoc-members:
   :show-inheritance:

Blackjack
---------

Casino-style blackjack with splits, doubles, and dealer AI.

.. automodule:: card_games.blackjack.blackjack
   :members:
   :undoc-members:
   :show-inheritance:

Blackjack GUI
~~~~~~~~~~~~~

Graphical user interface for blackjack.

.. automodule:: card_games.blackjack.gui
   :members:
   :undoc-members:
   :show-inheritance:

Uno
---

Classic Uno card game with AI opponents and special cards.

.. automodule:: card_games.uno.uno
   :members:
   :undoc-members:
   :show-inheritance:

Uno GUI
~~~~~~~

Graphical user interface for Uno.

.. automodule:: card_games.uno.gui
   :members:
   :undoc-members:
   :show-inheritance:

Common Card Utilities
---------------------

Shared card representations and utilities used across all card games.

.. automodule:: card_games.common.cards
   :members:
   :undoc-members:
   :show-inheritance:
